package model

import (
	"time"

	"go.mongodb.org/mongo-driver/bson/primitive"
)

const Collection = "product"

type Product struct {
	ID           primitive.ObjectID  `bson:"_id,omitempty" json:"id,omitempty"`
	StyleNumber  string              `bson:"styleNumber"`
	Title        ProductTitle        `bson:"title"`
	Description  string              `bson:"description"`
	Season       string              `bson:"season"`
	Brand        ProductBrand        `bson:"brand"`
	Care         string              `bson:"care"`
	MadeIn       string              `bson:"madeIn"`
	HsCode       string              `bson:"hsCode"`
	InfoSelect   string              `bson:"infoSelect"` // 商品信息默认选择哪个商品
	Colors       ProductColors       `bson:"colors"`
	Category     ProductCategory     `bson:"category"`
	Compositions ProductCompositions `bson:"compositions"`
	Fits         []string            `bson:"fits"`
	Genders      ProductGenders      `bson:"genders"`
	Models       []string            `bson:"models"`
	UpdateAt     time.Time           `bson:"updateAt,omitempty" json:"updateAt,omitempty"`
	CreateAt     time.Time           `bson:"createAt,omitempty" json:"createAt,omitempty"`
}

type Products []Product

type ProductGender string

type ProductGenders []ProductGender

const (
	GenderMan   ProductGender = "man"
	GenderWoman ProductGender = "woman"
	GenderBaby  ProductGender = "baby"
	GenderGirl  ProductGender = "girl"
	GenderBoy   ProductGender = "boy"
)

type ProductComposition struct {
	Part     string `bson:"part"`
	Material string `bson:"material"`
	Value    string `bson:"value"`
}

type ProductCompositions []ProductComposition

type ProductCategory struct {
	Id       string            `bson:"id"`
	Name     string            `bson:"name"`
	Children []ProductCategory `json:"children" bson:"children"`
}

type ProductColor struct {
	ColorCode  string           `bson:"colorCode"`
	Id         string           `bson:"id"`
	Name       string           `bson:"name"`
	BasicId    string           `bson:"basicId"`
	BasicName  string           `bson:"basicName"`
	InfoSelect string           `bson:"infoSelect"` // 商品信息默认选择哪个商品
	Skus       ProductColorSkus `bson:"skus"`
	Images     []string         `bson:"images"`
}

type ProductColors []ProductColor

type ProductColorSku struct {
	Pc3SkuId     string  `bson:"pc3SkuId"`
	Pc3ProductId string  `bson:"pc3ProductId"`
	SourceId     string  `bson:"sourceId"`
	SiteId       string  `bson:"siteId"`
	Size         string  `bson:"size"`
	Stock        int     `bson:"stock"`
	Price        float64 `bson:"price"`
	Currency     string  `bson:"currency"`
}

type ProductColorSkus []ProductColorSku

type ProductTitle struct {
	En string `bson:"en"`
	Cn string `bson:"cn"`
}

type ProductBrand struct {
	Id   string `bson:"id"`
	Name string `bson:"name"`
}
