package model

import (
	"git.chillcy.com/golang/chillcy/pkg/currency"
	"git.chillcy.com/golang/colorway/internal/pkg/database/mongo/types"
	"time"

	"go.mongodb.org/mongo-driver/bson/primitive"
)

type SitePlatformPriceConfig struct {
	ID               primitive.ObjectID `bson:"_id,omitempty" json:"id,omitempty"`
	Site             string             `json:"site" bson:"site"`
	Seller           types.Seller       `json:"seller" bson:"seller"` // 销售平台
	Enable           bool               `json:"enable" bson:"enable"` // 是否启用
	RoutePriceConfig `bson:",inline"`   // 路线价格配置
	UpdateAt         time.Time          `bson:"updateAt,omitempty" json:"updateAt,omitempty"`
	CreateAt         time.Time          `bson:"createAt,omitempty" json:"createAt,omitempty"`
}

type RoutePriceConfig struct {
	Route         string            `json:"route" bson:"route"`                 // 路线
	Currency      currency.Currency `json:"currency" bson:"currency"`           // 结算币种
	TaxRate       float64           `json:"taxRate" bson:"taxRate"`             // 税率
	MarginConfig  MarginConfig      `json:"marginConfig" bson:"marginConfig"`   // 加价率配置
	FreightConfig FreightConfig     `json:"freightConfig" bson:"freightConfig"` // 商家运费配置，默认是 0
	ExpressConfig ExpressConfig     `json:"expressConfig" bson:"expressConfig"` // 跨境快递配置，默认是0
}

type ExpressConfig struct {
	Express      float64      `json:"express" bson:"express"`           // 跨境快递费
	ExpressStyle ExpressStyle `json:"expressStyle" bson:"expressStyle"` // 跨境快递费计算方式
}

type ExpressStyle string

type FreightConfig struct {
	Freight             float64           `json:"freight" bson:"freight"`                         // 商家运费
	FreightStyle        FreightStyle      `json:"freightStyle" bson:"freightStyle" `              // 商家运费计算方式
	OverFreight         int               `json:"overFreight" bson:"overFreight"`                 // 计算方式是满免的时候会用到
	OverFreightCurrency currency.Currency `json:"overFreightCurrency" bson:"overFreightCurrency"` // 计算方式是满免的时候会用到
}

type FreightStyle string

type MarginConfig struct {
	MarginStyle MarginStyle `json:"marginStyle" bson:"marginStyle"` // 加价方式
	Margin      float64     `json:"margin" bson:"margin"`           // 加价率,加价方式为固定加价时使用
	Ladders     []Ladder    `json:"ladders" bson:"ladders"`         // 阶梯加价,加价方式为阶梯加价时使用
}

type MarginStyle string

type Ladder struct {
	Min     float64 `json:"min" bson:"min"`       // 最小值
	Max     float64 `json:"max" bson:"max"`       // 最大值
	Margin  float64 `json:"margin" bson:"margin"` // 加价率
	LastOne bool    `bson:"-"`
}
