package model

import "gorm.io/gorm"

type ColorSpu struct {
	gorm.Model
	CompleteSpuStyleNumber string `gorm:"uniqueIndex:style; size:50; not null"`
	ColorCode              string `gorm:"uniqueIndex:style; size:50;"`
	Color                  Color  `gorm:"embedded;embeddedPrefix:color_"`
	InfoSelect             string `gorm:"not null; size:24"` // 商品信息默认选择哪个商品

	// 外键
	// 多对一
	Skus   Skus   `gorm:"foreignKey:ColorSpuStyleNumber,ColorSpuColorCode; references:CompleteSpuStyleNumber,ColorCode; constraint:OnUpdate:CASCADE,OnDelete:CASCADE"`
	Images Images `gorm:"foreignKey:ColorSpuStyleNumber,ColorSpuColorCode; references:CompleteSpuStyleNumber,ColorCode; constraint:OnUpdate:CASCADE,OnDelete:CASCADE"`
}

type ColorSpus []ColorSpu

func (receiver ColorSpus) GetSkus() Skus {
	var skus Skus
	for _, spu := range receiver {
		skus = append(skus, spu.Skus...)
	}
	return skus
}

func (receiver ColorSpus) GetImages() Images {
	var images Images
	for _, spu := range receiver {
		images = append(images, spu.Images...)
	}
	return images
}

func (receiver ColorSpus) GetCompleteStyleNumbers() []string {
	var completeStyleNumbers []string
	for _, spu := range receiver {
		completeStyleNumbers = append(completeStyleNumbers, spu.CompleteSpuStyleNumber)
	}
	return completeStyleNumbers
}

func (receiver ColorSpus) GetColorCodes() []string {
	var colorCodes []string
	for _, spu := range receiver {
		colorCodes = append(colorCodes, spu.ColorCode)
	}
	return colorCodes
}

func (receiver ColorSpus) GetStyles() [][]interface{} {
	var styles [][]interface{}
	for _, spu := range receiver {
		styles = append(styles, []interface{}{spu.CompleteSpuStyleNumber, spu.ColorCode})
	}
	return styles
}

type Color struct {
	Id        string `gorm:"size:50; not null"`
	Name      string `gorm:"size:50; not null"`
	BasicId   string `gorm:"size:50; not null"`
	BasicName string `gorm:"size:50; not null"`
}
